@@ -193,9 +193,14 @@ class SSHClient(object):
     def _exec(self, cmd, promt_response,timeout=60):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
+            transport = self.__ssh.get_transport()
+            if not transport or not transport.is_active():
+                return ExecResult(1, "", "SSH连接已关闭或不可用")
+
+            channel = transport.open_session()
+            # 设置终端尺寸
+            channel.get_pty(width=80, height=100)
             if promt_response:
-                channel = self.__ssh.get_transport().open_session()
-                channel.get_pty(width=80, height=100)  # 获取虚拟终端
                 channel.exec_command(cmd)
                 output = ""
                 begin=datetime.now()
@@ -226,9 +231,11 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                channel = self.__ssh.get_transport().open_session()
-                channel.get_pty(width=80, height=100)  # 获取虚拟终端
-                stdin, stdout, stderr = channel.exec_command(cmd)
+                stdin, stdout, stderr = self.__ssh.exec_command(
+                    cmd,
+                    get_pty=True,
+                    timeout=timeout
+                )
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
